
set more off
clear all

use "$works/base_vf.dta", clear //tiene com_08

*==================================
* Table 1. Descriptive Statistics
*==================================

logout, save("$outputs/Summary Statistics.xml") excel replace: ///
tabstat SAH dist time age male sch couple nkids06 nkids717 wage part_org ///
h_skill m_skill l_skill primario secundario terciario r_norte r_sur r_santiago urban, ///
s(n mean sd min max) columns(statistics)


*============================================================================
* Figure 1. Long-distance commuting flow by region (2009) (Only percentages)
*============================================================================

* Labels for regions
label values codreg_c regions_lab 

tab codreg_c commute_reg [fw=expr_p], nofreq col 


*======================================================================
* Figure 2. Distribution of distances in kilometers and time (minutes)
*======================================================================

preserve

* Histogram Distance
*====================
gen n=1
egen n_com=sum(n)
egen n_com10=sum(n) if dist>=0 & dist<10
egen n_com20=sum(n) if dist>=10 & dist<20
egen n_com30=sum(n) if dist>=20 & dist<30
egen n_com40=sum(n) if dist>=30 & dist<40
egen n_com50=sum(n) if dist>=40 & dist<50
egen n_com60=sum(n) if dist>=50 & dist<60
egen n_com70=sum(n) if dist>=60 & dist<70
egen n_com80=sum(n) if dist>=70 & dist<80
egen n_com90=sum(n) if dist>=80 & dist<90
egen n_com100=sum(n) if dist>=90 & dist<100
egen n_com200=sum(n) if dist>=100 & dist<200
egen n_com300=sum(n) if dist>=200 & dist<300
egen n_com400=sum(n) if dist>=300 & dist<400
egen n_com500=sum(n) if dist>=400 & dist<500
egen n_com600=sum(n) if dist>=500 & dist<600
egen n_com700=sum(n) if dist>=600 & dist<700
egen n_com800=sum(n) if dist>=700 & dist<800
egen n_com900=sum(n) if dist>=800 & dist<900
egen n_com1000=sum(n) if dist>=900 & dist<1000
egen n_com1500=sum(n) if dist>=1000 & dist<1500
egen n_com2000=sum(n) if dist>=1500 & dist<2000
egen n_com4000=sum(n) if dist>=2000 & dist<4000

foreach i in "10" "20" "30" "40" "50" "60" "70" "80" "90" "100" "200" "300" "400" "500" "600" "700" "800" "900" "1000" "1500" "2000" "4000" {
egen ncom`i'=max(n_com`i')
gen p_com`i'=ncom`i'/n_com
}
*
drop n_com* ncom*

keep p_com*
duplicates drop p_com10, force

gen id=1
reshape long p_com, i(id) j(k) 

graph bar p_com, over(k, gap(5) label(labsize(vsmall) angle(45))) ///
				 bar(1, col(black)) graphregion(color(white)) ///
				 title("Panel A: Distance in Kilometers", col(black)) ylabel(,nogrid) ytitle("Percentage") ///
				 name(Hist_distance, replace)
restore


preserve

* Histogram Time
*===============
gen n=1
egen n_com=sum(n)
egen n_com10=sum(n) if time>=0 & time<10
egen n_com20=sum(n) if time>=10 & time<20
egen n_com30=sum(n) if time>=20 & time<30
egen n_com40=sum(n) if time>=30 & time<40
egen n_com50=sum(n) if time>=40 & time<50
egen n_com60=sum(n) if time>=50 & time<60
egen n_com70=sum(n) if time>=60 & time<70
egen n_com80=sum(n) if time>=70 & time<80
egen n_com90=sum(n) if time>=80 & time<90
egen n_com100=sum(n) if time>=90 & time<100
egen n_com200=sum(n) if time>=100 & time<200
egen n_com300=sum(n) if time>=200 & time<300
egen n_com400=sum(n) if time>=300 & time<400
egen n_com500=sum(n) if time>=400 & time<500
egen n_com600=sum(n) if time>=500 & time<600
egen n_com700=sum(n) if time>=600 & time<700
egen n_com800=sum(n) if time>=700 & time<800
egen n_com900=sum(n) if time>=800 & time<900
egen n_com1000=sum(n) if time>=900 & time<1000
*egen n_com1500=sum(n) if time>=1000 & time<1500
egen n_com2000=sum(n) if time>=1000 & time<2000
egen n_com4000=sum(n) if time>=2000 & time<4000

foreach i in "10" "20" "30" "40" "50" "60" "70" "80" "90" "100" "200" "300" "400" "500" "600" "700" "800" "900" "1000" /*"1500"*/ "2000" "4000" {
egen ncom`i'=max(n_com`i')
gen p_com`i'=ncom`i'/n_com
}
*
drop n_com* ncom*

keep p_com*
duplicates drop p_com10, force

gen id=1
reshape long p_com, i(id) j(k) 

graph bar p_com, over(k, gap(5) label(labsize(vsmall) angle(45))) ///
				 bar(1, col(black)) graphregion(color(white)) ///
				 title("Panel B: Distance in Minutes", col(black)) ylabel(,nogrid) ytitle("Percentage") ///
				 name(Hist_time, replace)
restore

				 
* Combine distance and time graphs
graph combine Hist_distance Hist_time, graphregion(color(white))
graph export "$graphs/Figure2.eps", as(eps) replace


*===============================
* Figure 3. Distribution of SAH
*===============================

histogram SAH, ///
	discrete width(0.5) percent addlabel xtitle("") xlabel(, valuelabel) ylabel(,nogrid) ///
	ytitle("Percentage (%)") scheme(sj) graphregion(color(white))
graph export "$graphs/Figure3.eps", as(eps) replace
	
	
	
